summaryrefslogtreecommitdiffstats
path: root/src/drawscreen.c
diff options
context:
space:
mode:
authorLewis Russell <lewis6991@gmail.com>2022-03-29 11:38:17 +0100
committerBram Moolenaar <Bram@vim.org>2022-03-29 11:38:17 +0100
commit1624639ec8a6c3c99e417a2990f2f02f0d0b6e10 (patch)
tree108c6915932564f48432e6c5f56d04653597d180 /src/drawscreen.c
parent24565cf27bc28cbd73f10e5ddf1e4ef53038a426 (diff)
patch 8.2.4644: redrawing too often when 'relativenumber' is setv8.2.4644
Problem: Redrawing too often when 'relativenumber' is set. Solution: Only redraw when the cursor line changed. (Lewis Russell, closes #10040)
Diffstat (limited to 'src/drawscreen.c')
-rw-r--r--src/drawscreen.c7
1 files changed, 4 insertions, 3 deletions
diff --git a/src/drawscreen.c b/src/drawscreen.c
index cb4757748f..9f9cb09602 100644
--- a/src/drawscreen.c
+++ b/src/drawscreen.c
@@ -2507,11 +2507,11 @@ win_update(win_T *wp)
}
else
{
- if (wp->w_p_rnu)
+ if (wp->w_p_rnu && wp->w_last_cursor_lnum_rnu != wp->w_cursor.lnum)
{
#ifdef FEAT_FOLDING
// 'relativenumber' set: The text doesn't need to be drawn, but
// the number column nearly always does.
fold_count = foldedCount(wp, lnum, &win_foldinfo);
if (fold_count != 0)
fold_line(wp, fold_count, &win_foldinfo, lnum, row);
@@ -2553,6 +2553,7 @@ win_update(win_T *wp)
// update w_last_cursorline.
wp->w_last_cursorline = wp->w_p_cul ? wp->w_cursor.lnum : 0;
#endif
+ wp->w_last_cursor_lnum_rnu = wp->w_p_rnu ? wp->w_cursor.lnum : 0;
#ifdef FEAT_VTP
// Rewrite the character at the end of the screen line.
@@ -2507,11 +2507,11 @@ win_update(win_T *wp)
{
#ifdef FEAT_FOLDING
- // 'relativenumber' set: The text doesn't need to be drawn, but
- // the number column nearly always does.
+ // 'relativenumber' set and the cursor moved vertically: The
+ // text doesn't need to be drawn, but the number column does.
fold_count = foldedCount(wp, lnum, &win_foldinfo);
if (fold_count != 0)